==> zio-aws-redshift_2.13-5.17.121.3-sources.jar: zio/aws/redshift/model/DescribeAccountAttributesResponse.scala <==
package zio.aws.redshift.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeAccountAttributesResponse(
    accountAttributes: Option[
      Iterable[zio.aws.redshift.model.AccountAttribute]
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.redshift.model.DescribeAccountAttributesResponse = {
    import DescribeAccountAttributesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.redshift.model.DescribeAccountAttributesResponse
      .builder()
      .optionallyWith(
        accountAttributes.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.accountAttributes)
      .build()
  }
  def asReadOnly
      : zio.aws.redshift.model.DescribeAccountAttributesResponse.ReadOnly =
    zio.aws.redshift.model.DescribeAccountAttributesResponse
      .wrap(buildAwsValue())
}
object DescribeAccountAttributesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.redshift.model.DescribeAccountAttributesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.redshift.model.DescribeAccountAttributesResponse =
      zio.aws.redshift.model.DescribeAccountAttributesResponse(
        accountAttributes.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def accountAttributes
        : Option[List[zio.aws.redshift.model.AccountAttribute.ReadOnly]]
    def getAccountAttributes: ZIO[Any, AwsError, List[
      zio.aws.redshift.model.AccountAttribute.ReadOnly
    ]] = AwsError.unwrapOptionField("accountAttributes", accountAttributes)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.redshift.model.DescribeAccountAttributesResponse
  ) extends zio.aws.redshift.model.DescribeAccountAttributesResponse.ReadOnly {
    override val accountAttributes
        : Option[List[zio.aws.redshift.model.AccountAttribute.ReadOnly]] = scala
      .Option(impl.accountAttributes())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.redshift.model.AccountAttribute.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.redshift.model.DescribeAccountAttributesResponse
  ): zio.aws.redshift.model.DescribeAccountAttributesResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-redshift_2.13-5.17.195.2-sources.jar: zio/aws/redshift/model/DescribeAccountAttributesResponse.scala <==
package zio.aws.redshift.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DescribeAccountAttributesResponse(
    accountAttributes: Optional[
      Iterable[zio.aws.redshift.model.AccountAttribute]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.redshift.model.DescribeAccountAttributesResponse = {
    import DescribeAccountAttributesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.redshift.model.DescribeAccountAttributesResponse
      .builder()
      .optionallyWith(
        accountAttributes.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.accountAttributes)
      .build()
  }
  def asReadOnly
      : zio.aws.redshift.model.DescribeAccountAttributesResponse.ReadOnly =
    zio.aws.redshift.model.DescribeAccountAttributesResponse
      .wrap(buildAwsValue())
}
object DescribeAccountAttributesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.redshift.model.DescribeAccountAttributesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.redshift.model.DescribeAccountAttributesResponse =
      zio.aws.redshift.model.DescribeAccountAttributesResponse(
        accountAttributes.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def accountAttributes
        : Optional[List[zio.aws.redshift.model.AccountAttribute.ReadOnly]]
    def getAccountAttributes: ZIO[Any, AwsError, List[
      zio.aws.redshift.model.AccountAttribute.ReadOnly
    ]] = AwsError.unwrapOptionField("accountAttributes", accountAttributes)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.redshift.model.DescribeAccountAttributesResponse
  ) extends zio.aws.redshift.model.DescribeAccountAttributesResponse.ReadOnly {
    override val accountAttributes
        : Optional[List[zio.aws.redshift.model.AccountAttribute.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.accountAttributes())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.redshift.model.AccountAttribute.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.redshift.model.DescribeAccountAttributesResponse
  ): zio.aws.redshift.model.DescribeAccountAttributesResponse.ReadOnly =
    new Wrapper(impl)
}
